@@ -32,19 +32,22 @@ var NAVTREEINDEX0 =
 "classZemberek.html#ae79a59a64c2acc8b8fe699e439676d65":[1,0,65,0],
 "classes.html":[1,1],
 "config_8h_source.html":[2,0,2],
+"configmake_8h_source.html":[2,0,0,1],
 "dir_36f3b70f3d31bc0225487818f327ce9b.html":[2,0,1,0],
 "dir_59425e443f801f1f2fd8bbe4959a3ccf.html":[2,0,1],
 "dir_6847591482baadf93bd6c0a2dd7b59f4.html":[2,0,0],
+"dir_f4a5301858d1fabfff9c3b058f1df93d.html":[2,0,0,0],
+"file_8h_source.html":[2,0,0,0,0],
 "files.html":[2,0],
 "hierarchy.html":[1,2],
 "index.html":[],
-"libgnu_2warn-on-use_8h_source.html":[2,0,0,4],
+"libgnu_2warn-on-use_8h_source.html":[2,0,0,6],
 "md_gl_mod_bootstrap_README.html":[0],
 "mock__provider_8h_source.html":[2,0,1,7],
-"msvc-inval_8h_source.html":[2,0,0,0],
-"msvc-nothrow_8h_source.html":[2,0,0,1],
+"msvc-inval_8h_source.html":[2,0,0,2],
+"msvc-nothrow_8h_source.html":[2,0,0,3],
 "pages.html":[],
-"relocatable_8h_source.html":[2,0,0,2],
+"relocatable_8h_source.html":[2,0,0,4],
 "structAppleSpellDictionary.html":[1,0,2],
 "structAppleSpellDictionary.html#a4747deb70ac09801ab92b5db476e94f1":[1,0,2,0],
 "structAppleSpellDictionary.html#ad9da863ef9016e81a073adfa94eef1da":[1,0,2,1],
@@ -246,8 +249,5 @@ var NAVTREEINDEX0 =
 "structEnchantDictionaryTestFixture.html#afb594b8069eb8a24d3094477bd7ea3e9":[1,0,52,31],
 "structEnchantGetPrefixDirTestFixture.html":[1,0,53],
 "structEnchantGetPrefixDirTestFixture.html#abee09d59aec73e7e3d48341f2cd5e422":[1,0,53,2],
-"structEnchantGetPrefixDirTestFixture.html#ad34fb2071d32b52af11f70e22dbaf577":[1,0,53,1],
-"structEnchantGetPrefixDirTestFixture.html#add23ebb2ccd267992f6922d6971eba5d":[1,0,53,0],
-"structEnchantPwlWithDictSuggs__TestFixture.html":[1,0,55],
-"structEnchantPwlWithDictSuggs__TestFixture.html#ae0b0156964c9de2432e033e300e5c969":[1,0,55,0]
+"structEnchantGetPrefixDirTestFixture.html#ad34fb2071d32b52af11f70e22dbaf577":[1,0,53,1]
 };
