@@ -1,7 +1,7 @@
 var indexSectionsWithContent =
 {
   0: "_abdehpz",
-  1: "_abdehpz",
+  1: "_adehpz",
   2: "b"
 };
 
